@@ -8,8 +8,8 @@ use layout::{DynamicLayout, Section};
 use crate::tui::app::{App, AppMode, Focus};
 use crate::tui::theme::Theme;
 use popups::{
-    render_cell_edit_overlay, render_file_create_confirm, render_help_popup, render_link_picker,
-    render_theme_picker,
+    render_cell_edit_overlay, render_command_palette, render_file_create_confirm,
+    render_help_popup, render_link_picker, render_save_width_confirm, render_theme_picker,
 };
 use ratatui::Frame;
 use ratatui::layout::{Constraint, Layout, Rect};
@@ -31,9 +31,11 @@ pub fn render(frame: &mut Frame, app: &mut App) {
     let area = frame.area();
 
     // Create dynamic main layout
+    // Show search bar if: outline search is active OR in document search mode (typing or viewing results)
+    let show_search_bar = app.show_search || app.mode == AppMode::DocSearch;
     let main_layout = DynamicLayout::vertical(area)
         .section(Section::Title, Constraint::Length(2))
-        .section_if(app.show_search, Section::Search, Constraint::Length(3))
+        .section_if(show_search_bar, Section::Search, Constraint::Length(3))
         .section(Section::Content, Constraint::Min(0))
         .section(Section::Status, Constraint::Length(1))
         .build();
@@ -99,6 +101,16 @@ pub fn render(frame: &mut Frame, app: &mut App) {
             render_file_create_confirm(frame, message, &app.theme);
         }
     }
+
+    // Render save width confirmation dialog
+    if matches!(app.mode, AppMode::ConfirmSaveWidth) {
+        render_save_width_confirm(frame, app.outline_width, &app.theme);
+    }
+
+    // Render command palette
+    if matches!(app.mode, AppMode::CommandPalette) {
+        render_command_palette(frame, app, &app.theme);
+    }
 }
 
 fn render_title_bar(frame: &mut Frame, app: &App, area: Rect) {
@@ -116,13 +128,76 @@ fn render_title_bar(frame: &mut Frame, app: &App, area: Rect) {
 }
 
 fn render_search_bar(frame: &mut Frame, app: &App, area: Rect) {
-    let search_text = format!("Search: {}_", app.search_query);
-    let paragraph = Paragraph::new(search_text)
+    // Unified search bar rendering for both outline and document search
+    let is_doc_search = app.mode == AppMode::DocSearch;
+
+    // Get the current query and display state
+    let (query, is_active, match_info) = if is_doc_search {
+        let info = if !app.doc_search_matches.is_empty() {
+            let current = app.doc_search_current_idx.unwrap_or(0) + 1;
+            let total = app.doc_search_matches.len();
+            format!(" [{}/{}]", current, total)
+        } else if !app.doc_search_query.is_empty() {
+            " [no matches]".to_string()
+        } else {
+            String::new()
+        };
+        (&app.doc_search_query, app.doc_search_active, info)
+    } else {
+        // Outline search
+        (&app.search_query, app.outline_search_active, String::new())
+    };
+
+    // Styling based on search type
+    let (label, title, accent_color) = if is_doc_search {
+        (
+            "Find",
+            " Content Search (Tab: switch to Outline) ",
+            Color::Cyan,
+        )
+    } else {
+        (
+            "Filter",
+            " Outline Search (Tab: switch to Content) ",
+            Color::Yellow,
+        )
+    };
+
+    // Build search bar with query
+    let query_display = if is_active {
+        format!("{}_", query)
+    } else {
+        query.clone()
+    };
+
+    let mut line_spans = vec![
+        Span::raw(format!("{}: ", label)),
+        Span::styled(
+            query_display,
+            Style::default()
+                .fg(accent_color)
+                .add_modifier(Modifier::BOLD),
+        ),
+        Span::raw(match_info),
+    ];
+
+    // Add hint text - consistent for both modes
+    let hint = if is_active {
+        "  (Esc, Ctrl+U)"
+    } else {
+        "  (Esc, Tab, /: edit)"
+    };
+    line_spans.push(Span::styled(
+        hint.to_string(),
+        Style::default().fg(Color::DarkGray),
+    ));
+
+    let paragraph = Paragraph::new(Line::from(line_spans))
         .block(
             Block::default()
                 .borders(Borders::ALL)
-                .border_style(Style::default().fg(Color::Yellow))
-                .title(" Filter Headings ")
+                .border_style(Style::default().fg(accent_color))
+                .title(title)
                 .style(Style::default().bg(Color::Rgb(30, 30, 50))),
         )
         .style(Style::default().fg(Color::White));
@@ -132,8 +207,14 @@ fn render_search_bar(frame: &mut Frame, app: &App, area: Rect) {
 
 fn render_outline(frame: &mut Frame, app: &mut App, area: Rect) {
     use crate::tui::app::DOCUMENT_OVERVIEW;
+    use util::build_highlighted_line;
 
     let theme = &app.theme;
+    let search_query = if app.show_search && !app.search_query.is_empty() {
+        Some(app.search_query.as_str())
+    } else {
+        None
+    };
 
     let items: Vec<ListItem> = app
         .outline_items
@@ -157,23 +238,27 @@ fn render_outline(frame: &mut Frame, app: &mut App, area: Rect) {
 
             // Color headings by level using theme
             let color = theme.heading_color(item.level);
+            let base_style = Style::default().fg(color);
 
-            // Special formatting for document overview (level 0) vs normal headings
-            let text = if item.text == DOCUMENT_OVERVIEW {
-                // Document overview: use 📄 icon instead of # prefix
-                format!(
-                    "{}{}{}📄 {}",
-                    indent, expand_indicator, bookmark_indicator, item.text
-                )
+            // Build prefix (indent + indicators + #'s)
+            let prefix_text = if item.text == DOCUMENT_OVERVIEW {
+                format!("{}{}{}📄 ", indent, expand_indicator, bookmark_indicator)
             } else {
-                // Normal headings: use # prefix
-                let prefix = "#".repeat(item.level);
+                let hashes = "#".repeat(item.level);
                 format!(
-                    "{}{}{}{} {}",
-                    indent, expand_indicator, bookmark_indicator, prefix, item.text
+                    "{}{}{}{} ",
+                    indent, expand_indicator, bookmark_indicator, hashes
                 )
             };
-            let line = Line::from(Span::styled(text, Style::default().fg(color)));
+
+            // Build line with search highlighting using shared utility
+            let line = build_highlighted_line(
+                vec![Span::styled(prefix_text, base_style)],
+                &item.text,
+                search_query,
+                base_style,
+                theme.search_match_style(),
+            );
 
             ListItem::new(line)
         })
@@ -252,7 +337,7 @@ fn render_content(frame: &mut Frame, app: &App, area: Rect) {
     };
 
     // Check if we should render raw source or enhanced markdown
-    let rendered_text = if app.show_raw_source {
+    let mut rendered_text = if app.show_raw_source {
         // Raw source view - show unprocessed markdown
         render_raw_markdown(&content_text, theme)
     } else {
@@ -276,6 +361,18 @@ fn render_content(frame: &mut Frame, app: &App, area: Rect) {
         )
     };
 
+    // Apply search highlighting only for document/content search mode
+    // Outline search (s) only filters headings, it doesn't highlight content
+    if app.mode == AppMode::DocSearch && !app.doc_search_query.is_empty() {
+        rendered_text = apply_search_highlighting(
+            rendered_text,
+            &app.doc_search_query,
+            app.doc_search_current_idx,
+            app.doc_search_matches.len(),
+            theme,
+        );
+    }
+
     let paragraph = Paragraph::new(rendered_text)
         .block(
             Block::default()
@@ -449,8 +546,7 @@ fn render_raw_markdown(content: &str, theme: &Theme) -> Text<'static> {
             // Replace tabs with spaces to avoid terminal rendering artifacts
             let line_content = line.replace('\t', "    ");
             // Raw content with plain text styling
-            let content_span =
-                Span::styled(line_content, Style::default().fg(theme.foreground));
+            let content_span = Span::styled(line_content, Style::default().fg(theme.foreground));
             Line::from(vec![line_num, content_span])
         })
         .collect();
@@ -486,6 +582,7 @@ fn render_markdown_enhanced(
                 level,
                 content,
                 inline,
+                ..
             } => {
                 // Render sub-heading with appropriate styling
                 let mut formatted = if !inline.is_empty() {
@@ -583,16 +680,19 @@ fn render_markdown_enhanced(
                         .unwrap_or(false);
 
                     // Check if a link within this list item is selected
-                    // Link sub_idx format: item_idx * 1000 + inline_idx + 100
+                    use crate::tui::interactive::{LINK_ITEM_MULTIPLIER, LINK_OFFSET};
                     let selected_link_inline_idx = selected_element_id.and_then(|id| {
                         if id.block_idx == block_idx {
                             id.sub_idx.and_then(|sub| {
                                 // Decode: check if this is a link sub_idx for this item
-                                if sub >= 100
-                                    && sub >= idx * 1000 + 100
-                                    && sub < (idx + 1) * 1000 + 100
+                                let item_link_base = idx * LINK_ITEM_MULTIPLIER + LINK_OFFSET;
+                                let next_item_link_base =
+                                    (idx + 1) * LINK_ITEM_MULTIPLIER + LINK_OFFSET;
+                                if sub >= LINK_OFFSET
+                                    && sub >= item_link_base
+                                    && sub < next_item_link_base
                                 {
-                                    Some(sub - idx * 1000 - 100)
+                                    Some(sub - item_link_base)
                                 } else {
                                     None
                                 }
@@ -713,11 +813,48 @@ fn render_markdown_enhanced(
                     }
 
                     // Render nested blocks within this list item (e.g., code blocks)
-                    for nested_block in &item.blocks {
+                    use crate::tui::interactive::{
+                        CODE_BLOCK_OFFSET, IMAGE_OFFSET, ITEM_MULTIPLIER, NESTED_MULTIPLIER,
+                        TABLE_OFFSET,
+                    };
+                    for (nested_idx, nested_block) in item.blocks.iter().enumerate() {
+                        // Check if this nested block is selected
+                        let is_nested_selected = selected_element_id
+                            .map(|id| {
+                                if id.block_idx != block_idx {
+                                    return false;
+                                }
+                                if let Some(sub) = id.sub_idx {
+                                    // Decode the sub_idx to check if it matches this nested block
+                                    let base =
+                                        idx * ITEM_MULTIPLIER + nested_idx * NESTED_MULTIPLIER;
+                                    sub == base + CODE_BLOCK_OFFSET
+                                        || sub == base + TABLE_OFFSET
+                                        || sub == base + IMAGE_OFFSET
+                                } else {
+                                    false
+                                }
+                            })
+                            .unwrap_or(false);
+
                         let nested_lines = render_block_to_lines(nested_block, highlighter, theme);
-                        for nested_line in nested_lines {
-                            // Add indentation for nested content (align with list item text)
-                            let mut indented_spans = vec![Span::raw("     ")]; // 5 spaces indent
+                        for (line_idx, nested_line) in nested_lines.into_iter().enumerate() {
+                            let mut indented_spans = vec![];
+
+                            // Add selection indicator on first line of nested block
+                            if is_nested_selected && line_idx == 0 {
+                                indented_spans.push(Span::styled(
+                                    "→ ",
+                                    Style::default()
+                                        .fg(theme.selection_indicator_fg)
+                                        .bg(theme.selection_indicator_bg)
+                                        .add_modifier(Modifier::BOLD),
+                                ));
+                                indented_spans.push(Span::raw("   ")); // 3 spaces (5 - 2 for arrow)
+                            } else {
+                                indented_spans.push(Span::raw("     ")); // 5 spaces indent
+                            }
+
                             indented_spans.extend(nested_line.spans);
                             lines.push(Line::from(indented_spans));
                         }
@@ -893,6 +1030,151 @@ fn render_markdown_enhanced(
     Text::from(lines)
 }
 
+/// Apply search highlighting to rendered text while preserving original span styles.
+/// This function overlays search highlight styles on top of existing styling (links, bold, etc.)
+fn apply_search_highlighting(
+    text: Text<'static>,
+    query: &str,
+    current_match_idx: Option<usize>,
+    total_matches: usize,
+    theme: &Theme,
+) -> Text<'static> {
+    if query.is_empty() {
+        return text;
+    }
+
+    let query_lower = query.to_lowercase();
+    let mut new_lines = Vec::new();
+    let mut match_counter = 0usize;
+
+    for line in text.lines.into_iter() {
+        // Build span index: (byte_start, byte_end, span_index)
+        let mut span_ranges: Vec<(usize, usize, usize)> = Vec::new();
+        let mut byte_pos = 0;
+        for (idx, span) in line.spans.iter().enumerate() {
+            let span_len = span.content.len();
+            span_ranges.push((byte_pos, byte_pos + span_len, idx));
+            byte_pos += span_len;
+        }
+
+        // Join all spans to get the full line text for searching
+        let full_text: String = line.spans.iter().map(|s| s.content.as_ref()).collect();
+        let full_text_lower = full_text.to_lowercase();
+
+        // Find all occurrences of the query in this line (non-overlapping)
+        let mut matches_in_line: Vec<(usize, usize)> = Vec::new();
+        let mut search_start = 0;
+        let query_len = query.len();
+
+        while let Some(rel_pos) = full_text_lower[search_start..].find(&query_lower) {
+            let byte_start = search_start + rel_pos;
+            let byte_end = byte_start + query_len;
+
+            // Verify we're on valid char boundaries
+            if full_text.is_char_boundary(byte_start) && full_text.is_char_boundary(byte_end) {
+                matches_in_line.push((byte_start, byte_end));
+            }
+
+            search_start = byte_end;
+            if search_start >= full_text_lower.len() {
+                break;
+            }
+        }
+
+        if matches_in_line.is_empty() {
+            // No matches in this line - keep original
+            new_lines.push(line);
+        } else {
+            // Rebuild line with highlighted matches while preserving original styles
+            let mut new_spans: Vec<Span<'static>> = Vec::new();
+
+            // Process each original span and split it at match boundaries
+            for (span_start, span_end, span_idx) in &span_ranges {
+                let original_span = &line.spans[*span_idx];
+                let original_style = original_span.style;
+                let span_text = original_span.content.as_ref();
+
+                // Find which matches overlap with this span
+                let mut current_pos = 0; // position within the span
+
+                for (match_start, match_end) in &matches_in_line {
+                    // Skip matches that are entirely before this span
+                    if *match_end <= *span_start {
+                        continue;
+                    }
+                    // Stop if match is entirely after this span
+                    if *match_start >= *span_end {
+                        break;
+                    }
+
+                    let is_current = total_matches > 0 && current_match_idx == Some(match_counter);
+
+                    // Calculate positions relative to span
+                    let rel_match_start = match_start.saturating_sub(*span_start);
+                    let rel_match_end = (*match_end).min(*span_end) - *span_start;
+
+                    // Add text before the match (with original style)
+                    if current_pos < rel_match_start {
+                        if let Some(before_text) =
+                            safe_slice(span_text, current_pos, rel_match_start)
+                        {
+                            if !before_text.is_empty() {
+                                new_spans
+                                    .push(Span::styled(before_text.to_string(), original_style));
+                            }
+                        }
+                    }
+
+                    // Add the matched portion (with search highlight style)
+                    let highlight_style = if is_current {
+                        theme.search_current_style()
+                    } else {
+                        theme.search_match_style()
+                    };
+
+                    let actual_start = rel_match_start.max(current_pos);
+                    if let Some(match_text) = safe_slice(span_text, actual_start, rel_match_end) {
+                        if !match_text.is_empty() {
+                            new_spans.push(Span::styled(match_text.to_string(), highlight_style));
+                        }
+                    }
+
+                    current_pos = rel_match_end;
+
+                    // Only increment counter when we finish the match (match_end <= span_end)
+                    if *match_end <= *span_end {
+                        match_counter += 1;
+                    }
+                }
+
+                // Add remaining text after all matches in this span (with original style)
+                if current_pos < span_text.len() {
+                    if let Some(after_text) = safe_slice(span_text, current_pos, span_text.len()) {
+                        if !after_text.is_empty() {
+                            new_spans.push(Span::styled(after_text.to_string(), original_style));
+                        }
+                    }
+                }
+            }
+
+            new_lines.push(Line::from(new_spans));
+        }
+    }
+
+    Text::from(new_lines)
+}
+
+/// Safely slice a string at byte boundaries, returning None if boundaries are invalid
+fn safe_slice(s: &str, start: usize, end: usize) -> Option<&str> {
+    if start > end || end > s.len() {
+        return None;
+    }
+    if !s.is_char_boundary(start) || !s.is_char_boundary(end) {
+        return None;
+    }
+    Some(&s[start..end])
+}
+
 fn render_block_to_lines(
     block: &ContentBlock,
     highlighter: &SyntaxHighlighter,
@@ -905,6 +1187,7 @@ fn render_block_to_lines(
             level,
             content,
             inline,
+            ..
         } => {
             // Render heading with appropriate styling
             let mut formatted = if !inline.is_empty() {
